# Collectibles

A library to manage collections (lists, dictionaries and tuples) of dataclasses and pydantic models.
A dataclasses-style syntax automatically creates the methods for retrieving collections of your dataclass attributes without having to write the boilerplate comprehensions.

The library is fully typed so your IDE will thank you 😄

## Installation

```bash
pip install collectibles
```

## Usage

See `examples.py` for a full example.

## Contributions

Contributions are welcome! Please open an issue or a PR. We're currently looking to increase our support for Pydantic 1.x and 2.x models.
